@@ -1,8 +1,7 @@
 #!/usr/bin/perl -w
 
-
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2005 Jrn Reder <joern AT zyn.de>.
+# Copyright (C) 2005-2015 by Jörn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -11,8 +10,6 @@
 
 use strict;
 
-use lib 'lib';
-use lib qw(../lib);
 use Event::RPC::Client;
 use Getopt::Std;
 
@@ -33,10 +30,10 @@ Options:
 __EOU
 
 sub HELP_MESSAGE {
-	my ($fh) = @_;
-	$fh ||= \*STDOUT;
-	print $fh $USAGE;
-	exit;
+    my ($fh) = @_;
+    $fh ||= \*STDOUT;
+    print $fh $USAGE;
+    exit;
 }
 
 main: {
@@ -49,12 +46,12 @@ main: {
 
     my %auth_args;
     if ( $opts{a} ) {
-      my ($user, $pass) = split(":", $opts{a}); 
-      $pass = Event::RPC->crypt($user,$pass);
-      %auth_args = (
-	auth_user => $user,
-	auth_pass => $pass,
-      );
+        my ($user, $pass) = split(":", $opts{a}); 
+        $pass = Event::RPC->crypt($user,$pass);
+        %auth_args = (
+            auth_user => $user,
+            auth_pass => $pass,
+        );
     }
 
     #-- Host parameter
@@ -65,31 +62,33 @@ main: {
     #-- in the correspondent packages.
     my $client;
     $client = Event::RPC::Client->new (
-      host     => $host,
-      port     => 5555,
-      ssl      => $ssl,
-      %auth_args,
-      error_cb => sub {
-        my ($client, $error) = @_;
-      	print "An RPC error occured: $_[0]";
-	print "Disconnect and exit.\n";
-	$client->disconnect if $client;
-	exit
-      },
-      classes => [ "Test_class" ],
+        host     => $host,
+        port     => 5555,
+        ssl      => $ssl,
+        %auth_args,
+        error_cb => sub {
+            my ($client, $error) = @_;
+            print "An RPC error occured!\n> $error";
+            print "Disconnect and exit.\n";
+            $client->disconnect if $client;
+            exit;
+        },
+        classes => [ "Test_class" ],
     );
 
     $client->connect;
 
     print "\nConnected to localhost:5555\n\n";
     print "Server version:  ".$client->get_server_version,"\n";
-    print "Server protocol: ".$client->get_server_protocol,"\n\n";
+    print "Server protocol: ".$client->get_server_protocol,"\n";
+    print "Message format:  ".eval { $client->get_message_format },"\n";
+    print "\n";
 
     #-- So the call to Event::RPC::Test->new is handled transparently
     #-- by Event::RPC::Client
     print "** Create object on server\n";
     my $object = Test_class->new (
-	    data => "Initial data",
+            data => "Initial data",
     );
     print "=> Object created with data: '".$object->get_data."'\n\n";
 
